Microformats Module
===================

Microformats module for Drupal 8 incorporates indieweb/php-mf2 3.0+ PHP library:
https://github.com/indieweb/php-mf2/

Composer and symfony autoloader incorporated in Drupal 8 make microformat functions
available to any module. The microformats library can fetch and parse remote strings
and output structured PHP objects.

Microformats are an important general syntax for specifications like h-card,
h-entry and webmentions. By leveraging microformats and other PHP libraries already
available at [github.com/indieweb](https://github.com/indieweb/) it should be possible to implement many
of these formats in Drupal with minimal code duplication.

Contact info feature
--------------------

This part of the module allows you to display your contact information in a block
anywhere on your site. Your information is automatically formatted using the hCard
microformat, and it can easily be customized in your theme by modifying the provided template.

Edit your information by filling out an easy to use form.
Protects your email address from spammers if you also install the [spamspan](https://www.drupal.org/project/spamspan)
module.

All contact information fields made available as tokens.
This module is intended to be used on smaller brochure sites or blogs, but can be
useful for any site that needs to display a single primary contact block.

For a similar solution for Drupal 6, see the [hCard](https://www.drupal.org/project/hcard) module.

Microformats and the Indieweb
-----------------------------

* [Microformats.org]( http://microformats.org/)
* [Wiki]( http://microformats.org/wiki/Main_Page)
* [IndieWebCamp related development]( https://indiewebcamp.com/microformats)
* [Text source]( https://indiewebcamp.com/microformats)

Microformats are extensions to HTML for marking up people, organizations, events, locations, blog posts, products,
reviews, resumes, recipes etc. Sites use microformats to publish a standard API that is consumed and used by search
engines, aggregators, and other tools.

The IndieWeb makes heavy use of:
* `h-card` to mark up profiles and authors in published posts, then consumed by code
(e.g. reply-contexts, readers) for authorship and more.
* `h-entry` to markup posts, replies, etc., then consumed by code for displaying,
summarizing, replying.
* `in-reply-to` to markup links from replies to original posts, then consumed by code for
displaying comments, comment threads, etc.
* `XFN` for relationships, and identity consolidation (rel=me), consumed by code for
IndieAuth etc.

More module and support info
----------------

* Module URL: https://www.drupal.org/project/microformats

* Please submit issues here: https://www.drupal.org/project/issues/microformats

* Mark external library issues as "Code-External Libraries" category.

* More indieweb and microformat parser libraries here: https://github.com/indieweb/

* Related modules: See [Indieweb](https://drupal.org/project/indieweb) and
[Linkback](https://drupal.org/project/linkback) for other related features to this module.

This module is under development for Drupal 8/9 since May 2016.

php-mf2 info
------------

From the [Readme]( https://github.com/indieweb/php-mf2/blob/master/README.md):

php-mf2 is a pure, generic microformats-2 parser. It makes HTML as easy to consume as JSON.

Instead of having a hard-coded list of all the different microformats, it follows a set of procedures to handle
different property types (e.g. p- for plaintext, u- for URL, etc). This allows for a very small and maintainable parser.

- To fetch microformats from a URL, call `Mf2\fetch($url)`
- To parse microformats from HTML, call `Mf2\parse($html, $url)`, where `$url` is the URL from which `$html` was loaded,
if any. This parameter is required for correct relative URL parsing and must not be left out unless parsing HTML which
is not loaded from the web.

Developers
----------

* Microformats for Drupal 8 by [Dan Feidt]( https://drupal.org/u/hongpong ). 2020 Updates by
[Benjamin Melançon](https://drupal.org/u/mlncn)
* Sitewide Contact Info for Drupal 8 by [Karthikeyan Manivasagam]( https://www.drupal.org/u/karthikeyan-manivasagam )
* Originally developed by [Benjamin Doherty]( https://drupal.org/u/bangpound )
for Drupal 5.x 2006-2007
* The [Indieweb community]( https://github.com/indieweb )
